# UI/UX Feedback

**ID:** Feedback-20260129-161641
**URL:** idea://002. Feature-Themes/mockups/themes-toolbox-v1.html
**Date:** 2026-01-29 16:16:51

## Selected Elements

- `{'selector': 'div.modal-title', 'parents': ['div#modalOverlay', 'div.modal', 'div.modal-header']}`

## Feedback

make the text bigger

## Screenshot

![Screenshot](./page-screenshot.png)
